@@ -248,9 +248,9 @@ class Group:
         yp = np.zeros(self.dim_y)
         for body in self.bodies:
             if type(body) is bodies.RigidBody:
-                e2 = a2+7
+                e2 = a2 + 7
             elif type(body) is bodies.RigidBody1D:
-                e2 = a2+1
+                e2 = a2 + 1
             # collect kinematic equations
             yp[a2:e2] = body.kinematic_ode()
             a2 = e2
@@ -262,9 +262,9 @@ class Group:
         a1 = 0
         for body in self.bodies:
             if type(body) is bodies.RigidBody:
-                e1 = a1+6
+                e1 = a1 + 6
             elif type(body) is bodies.RigidBody1D:
-                e1 = a1+1
+                e1 = a1 + 1
             # collect kinematic equations
             b[a1:e1] = body.force_moment()
             a1 = e1
@@ -315,11 +315,11 @@ class Group:
         a2 = 0
         for body in self.bodies:
             if type(body) is bodies.RigidBody:
-                e1 = a1+7
-                e2 = a2+6
+                e1 = a1 + 7
+                e2 = a2 + 6
             elif type(body) is bodies.RigidBody1D:
-                e1 = a1+1
-                e2 = a2+1
+                e1 = a1 + 1
+                e2 = a2 + 1
             y[a1:e1] = body.y
             z[a2:e2] = body.z
             a1 = e1
@@ -397,7 +397,7 @@ class AnimationSaver:
 
         for m in mm:
             if m.animation is not None:
-                m.animation.position_saver.save(m.rSPK)
+                m.animation.position_saver.save(m.r0P0)
 
         with open(self.filename, 'wb') as file:
             pickle.dump(ta, file)
